@@ -1,12 +1,18 @@
 #ifndef DEBUG_H
 #define DEBUG_H
 
+#if __GNUC__
 #pragma GCC diagnostic ignored "-Wmissing-field-initializers"
 #pragma GCC diagnostic ignored "-Wunused-parameter"
+#endif
+#if __clang__
+#pragma clang diagnostic ignored "-Wunknown-warning-option"
+#pragma clang diagnostic ignored "-Wno-unknown-pragmas"
+#pragma clang diagnostic ignored "-Wvla-cxx-extension"
+#endif
 
 #ifdef DEBUG
 extern bool debug;
-extern bool debug_z;
 
 #define DBG if (debug)
 #define MSG(x) DBG tlog x
