@@ -356,8 +356,8 @@ void YWMApp::subdirs(const char* subdir, bool themeOnly, MStringArray& paths) {
         upath confDir(YApplication::getConfigDir());
         upath libsDir(YApplication::getLibDir());
         upath themeFile(themeName);
-        upath themeDir(themeFile.getExtension().isEmpty()
-                       ? themeFile : themeFile.parent());
+        upath themeDir(themeFile.path().endsWith(".theme")
+                       ? themeFile.parent() : themeFile);
 
         if (themeDir.isAbsolute()) {
             if (privDir.dirExists()) {
@@ -957,6 +957,16 @@ void YWMApp::setFocusMode(FocusModel mode) {
     WMConfig::setDefaultFocus(mode);
 }
 
+void YWMApp::launchHelp(const char* file) {
+    const char* args[] = { ICEHELPEXE, file, nullptr };
+    upath path;
+    if (strchr(file, '/') == nullptr) {
+        path = upath(ICEHELPIDX).parent() + file;
+        args[1] = path.string();
+    }
+    runProgram(ICEHELPEXE, args);
+}
+
 void YWMApp::actionPerformed(YAction action, unsigned int /*modifiers*/) {
     if (action == actionLogout) {
         doLogout(Logout);
@@ -1016,6 +1026,26 @@ void YWMApp::actionPerformed(YAction action, unsigned int /*modifiers*/) {
         setFocusMode(FocusCustom);
     } else if (action == actionRefresh) {
         refreshDesktop();
+    } else if (action == actionHelpManual) {
+        launchHelp(ICEHELPIDX);
+    } else if (action == actionHelpIcewm) {
+        launchHelp("icewm.1.html");
+    } else if (action == actionHelpIcewmbg) {
+        launchHelp("icewmbg.1.html");
+    } else if (action == actionHelpIcesound) {
+        launchHelp("icesound.1.html");
+    } else if (action == actionHelpIcesh) {
+        launchHelp("icesh.1.html");
+    } else if (action == actionHelpEnv) {
+        launchHelp("icewm-env.5.html");
+    } else if (action == actionHelpKeys) {
+        launchHelp("icewm-keys.5.html");
+    } else if (action == actionHelpStartup) {
+        launchHelp("icewm-startup.5.html");
+    } else if (action == actionHelpToolbar) {
+        launchHelp("icewm-toolbar.5.html");
+    } else if (action == actionHelpWinoptions) {
+        launchHelp("icewm-winoptions.5.html");
     } else if (action == actionAbout) {
         if (aboutDlg == nullptr)
             aboutDlg = new AboutDlg(this);
@@ -1062,10 +1092,7 @@ void YWMApp::actionPerformed(YAction action, unsigned int /*modifiers*/) {
             ctrlAltDelete->activate();
     }
     else if (action == actionWindowList) {
-        if (windowList->visible())
-            windowList->handleClose();
-        else
-            windowList->showFocused(-1, -1);
+        toggleWindowList();
     } else if (action == actionWinOptions) {
         loadWinOptions(findConfigFile("winoptions"));
     } else if (action == actionReloadKeys) {
@@ -1078,6 +1105,8 @@ void YWMApp::actionPerformed(YAction action, unsigned int /*modifiers*/) {
         }
     } else if (action == actionCollapseTaskbar && taskBar) {
         taskBar->handleCollapseButton();
+    } else if (action == actionToolbar && taskBar) {
+        taskBar->initToolbar();
     } else {
         for (int w = 0; w < workspaceCount; w++) {
             if (workspaceActionActivate[w] == action) {
@@ -1088,6 +1117,28 @@ void YWMApp::actionPerformed(YAction action, unsigned int /*modifiers*/) {
     }
 }
 
+void YWMApp::toggleWindowList() {
+    bool vis = windowList->visible();
+    if (vis) {
+        YFrameWindow* fram = windowList->getFrame();
+        YRect clnt(windowList->geometry());
+        YRect dtop(clnt.intersect(desktop->geometry()));
+        unsigned long sum = 0;
+        for (YFrameWindow* p = fram->prevLayer(); p; p = p->prevLayer()) {
+            if (p->visible()) {
+                YRect rect(dtop.intersect(p->geometry()));
+                sum += rect.pixels();
+            }
+        }
+        if (dtop.pixels() < sum + clnt.pixels() / 2)
+            vis = false;
+    }
+    if (vis)
+        windowList->handleClose();
+    else
+        windowList->showFocused(-1, -1);
+}
+
 void YWMApp::initFocusCustom() {
     cfoption focus_prefs[] = {
         OBV("ClickToFocus",              &clickFocus,                ""),
@@ -1428,8 +1479,6 @@ YWMApp::YWMApp(int *argc, char ***argv, const char *displayName,
 
     manager->grabKeys();
 
-    manager->setupRootProxy();
-
 #ifdef CONFIG_SESSION
     if (haveSessionManager())
         loadWindowInfo();
@@ -1807,6 +1856,9 @@ static void print_configured(const char *argv0) {
 #endif
 #ifdef CONFIG_XRANDR
     " xrandr"
+#endif
+#if HAVE_XRES
+    " xres"
 #endif
     "\n";
     printf(_("%s configured options:%s\n"), argv0,
@@ -1896,8 +1948,6 @@ int main(int argc, char **argv) {
 #ifdef DEBUG
             else if (is_long_switch(*arg, "debug"))
                 debug = true;
-            else if (is_long_switch(*arg, "debug-z"))
-                debug_z = true;
 #endif
             else
                 warn(_("Unrecognized option '%s'."), *arg);
@@ -2012,24 +2062,8 @@ void YWMApp::handleMsgBox(YMsgBox *msgbox, int operation) {
 }
 
 void YWMApp::handleSMAction(WMAction message) {
-    static const pair<WMAction, EAction> pairs[] = {
-        { ICEWM_ACTION_LOGOUT,        actionLogout },
-        { ICEWM_ACTION_CANCEL_LOGOUT, actionCancelLogout },
-        { ICEWM_ACTION_REBOOT,        actionReboot },
-        { ICEWM_ACTION_SHUTDOWN,      actionShutdown },
-        { ICEWM_ACTION_ABOUT,         actionAbout },
-        { ICEWM_ACTION_WINDOWLIST,    actionWindowList },
-        { ICEWM_ACTION_RESTARTWM,     actionRestart },
-        { ICEWM_ACTION_SUSPEND,       actionSuspend },
-        { ICEWM_ACTION_WINOPTIONS,    actionWinOptions },
-        { ICEWM_ACTION_RELOADKEYS,    actionReloadKeys },
-        { ICEWM_ACTION_ICEWMBG,       actionIcewmbg },
-        { ICEWM_ACTION_REFRESH,       actionRefresh },
-        { ICEWM_ACTION_HIBERNATE,     actionHibernate },
-    };
-    for (auto p : pairs)
-        if (message == p.left)
-            return actionPerformed(p.right);
+    if (inrange<int>(message, 2, LAST_ICEWM_ACTION))
+        actionPerformed(YAction(EAction(message)));
 }
 
 void YWMApp::refreshDesktop() {
