@@ -230,7 +230,7 @@ public:
         moveTarget(zdown);
     }
 
-    void cancel() override {
+    void cancelItem() override {
         ZItem last = fLastItem;
         ZItem act = fActiveItem;
         fLastItem.reset();
@@ -246,7 +246,7 @@ public:
         }
     }
 
-    void accept() override {
+    void acceptItem() override {
         ZItem act = fActiveItem;
         if (act) {
             if (act.client != act.frame->client())
@@ -255,7 +255,7 @@ public:
             if (act.frame->isFullscreen())
                 act.frame->updateLayer();
         } else {
-            cancel();
+            cancelItem();
         }
     }
 
@@ -477,17 +477,21 @@ void SwitchWindow::close() {
 }
 
 void SwitchWindow::cancel() {
+    YRestackLock restack;
     close();
-    zItems->cancel();
+    zItems->cancelItem();
 
     YFrameWindow* f = manager->getFocus();
     if (f && f->isFullscreen() && f->getActiveLayer() != WinLayerFullscreen)
         f->updateLayer();
+    manager->restackWindows();
 }
 
 void SwitchWindow::accept() {
+    YRestackLock restack;
     close();
-    zItems->accept();
+    zItems->acceptItem();
+    manager->restackWindows();
 }
 
 SwitchWindow::~SwitchWindow() {
